==> abiword-plugins-2.5.0.tar.gz: abiword-plugins-2.5.0/wp/impexp/opml/xp/ie_imp_OPML.h <==
/* -*- mode: C++; tab-width: 4; c-basic-offset: 4; -*- */

/* AbiWord
 * Copyright (C) 2001 AbiSource, Inc.  
 * 
 * This program is free software; you can redistribute it and/or
 * modify it under the terms of the GNU General Public License
 * as published by the Free Software Foundation; either version 2
 * of the License, or (at your option) any later version.
 * 
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 * 
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA
 * 02111-1307, USA.
 */


#ifndef IE_IMP_OPML_H
#define IE_IMP_OPML_H

#include "ie_imp_XML.h"
#include "fl_AutoNum.h"


class ABI_EXPORT IE_Imp_OPML_Sniffer : public IE_ImpSniffer
{
	friend class IE_Imp;

public:
	IE_Imp_OPML_Sniffer(const char *name);
	virtual ~IE_Imp_OPML_Sniffer() {}

	virtual const IE_SuffixConfidence * getSuffixConfidence ();
	virtual const IE_MimeConfidence * getMimeConfidence () { return NULL; }
	virtual			UT_Confidence_t recognizeContents (const char * szBuf, UT_uint32 iNumbytes);
	virtual bool	getDlgLabels (const char ** szDesc, const char ** szSuffixList, IEFileType * ft);
	virtual			UT_Error constructImporter (PD_Document * pDocument, IE_Imp ** ppie);
};

class ABI_EXPORT IE_Imp_OPML : public IE_Imp_XML
{
public:
	IE_Imp_OPML(PD_Document * pDocument);
	~IE_Imp_OPML(); 

	void			startElement(const XML_Char *name, const XML_Char **atts);
	void			endElement(const XML_Char *name);
	void			charData(const XML_Char *s, int len);

private:

	void			_createBullet(void);
	void			_createList(void);

	UT_UTF8String	m_sMetaTag;
	UT_uint32		m_iOutlineDepth;
	UT_uint32		m_iCurListID;
	UT_GenericVector<fl_AutoNum *> m_utvLists;
};

#endif /* IE_IMP_OPML_H */

==> abiword-plugins-2.5.2.tar.gz: abiword-plugins-2.5.2/wp/impexp/opml/xp/ie_imp_OPML.h <==
/* -*- mode: C++; tab-width: 4; c-basic-offset: 4; -*- */

/* AbiWord
 * Copyright (C) 2001 AbiSource, Inc.  
 * 
 * This program is free software; you can redistribute it and/or
 * modify it under the terms of the GNU General Public License
 * as published by the Free Software Foundation; either version 2
 * of the License, or (at your option) any later version.
 * 
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 * 
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA
 * 02111-1307, USA.
 */


#ifndef IE_IMP_OPML_H
#define IE_IMP_OPML_H

#include "ie_imp_XML.h"
#include "fl_AutoNum.h"


class ABI_EXPORT IE_Imp_OPML_Sniffer : public IE_ImpSniffer
{
	friend class IE_Imp;

public:
	IE_Imp_OPML_Sniffer(const char *name);
	virtual ~IE_Imp_OPML_Sniffer() {}

	virtual const IE_SuffixConfidence * getSuffixConfidence ();
	virtual const IE_MimeConfidence * getMimeConfidence () { return NULL; }
	virtual			UT_Confidence_t recognizeContents (const char * szBuf, UT_uint32 iNumbytes);
	virtual bool	getDlgLabels (const char ** szDesc, const char ** szSuffixList, IEFileType * ft);
	virtual			UT_Error constructImporter (PD_Document * pDocument, IE_Imp ** ppie);
};

class ABI_EXPORT IE_Imp_OPML : public IE_Imp_XML
{
public:
	IE_Imp_OPML(PD_Document * pDocument);
	~IE_Imp_OPML(); 

	void			startElement(const gchar *name, const gchar **atts);
	void			endElement(const gchar *name);
	void			charData(const gchar *s, int len);

private:

	void			_createBullet(void);
	void			_createList(void);

	UT_uint32		m_iCurListID;
	UT_uint32		m_iOutlineDepth;
	UT_UTF8String	m_sMetaTag;
	UT_GenericVector<fl_AutoNum *> m_utvLists;
};

#endif /* IE_IMP_OPML_H */
